# `yld`

`yld` (YIELD) aims to make Git tag deployments less tedious and repetitive.


## How it works

```
$ yld --minor

```

## Installation

```
$ pip install yld

```

**Note:** This is a Python 3 only package.
